@@ -110,7 +110,6 @@ def upload_to_s3(filename: str, folder: str = "stats/") -> dict:
     :param folder: str (folder from s3)
     :return: dict
     """
-    print(f"=== IN BOTO3 {filename}")
     s3 = boto3.resource('s3')
     GB = 1024 ** 3
     config = TransferConfig(multipart_threshold=int(GB / 3))
@@ -118,6 +117,10 @@ def upload_to_s3(filename: str, folder: str = "stats/") -> dict:
         s3_filename = filename[5:]
     else:
         s3_filename = filename
+    if folder.startswith('/'):
+        folder = folder[1:]
+    if not folder.endswith('/'):
+        folder = f'{folder}/'
     s3.meta.client.upload_file(
         filename,
         BUCKET_NAME,
@@ -139,6 +142,10 @@ def check_file_exist(filename: str, folder: str = "stats/") -> bool:
     bucket = s3.Bucket(BUCKET_NAME)
     if filename.startswith('/tmp/'):
         filename = filename[5:]
+    if folder.startswith('/'):
+        folder = folder[1:]
+    if not folder.endswith('/'):
+        folder = f'{folder}/'
     key = folder + filename
     objs = list(bucket.objects.filter(Prefix=key))
     if len(objs) > 0 and objs[0].key == key:
@@ -161,6 +168,10 @@ def get_file_link(
     :return: str
     """
     client = boto3.client('s3')
+    if folder.startswith('/'):
+        folder = folder[1:]
+    if not folder.endswith('/'):
+        folder = f'{folder}/'
     if filename.startswith('/tmp/'):
         filename = filename[5:]
     if suffix in filename:
@@ -260,6 +271,10 @@ def delete_s3_file(filename: str, folder: str, suffix: str) -> str:
     client = boto3.client('s3')
     if suffix not in filename:
         filename = f"{filename}{suffix}"
+    if folder.startswith('/'):
+        folder = folder[1:]
+    if not folder.endswith('/'):
+        folder = f'{folder}/'
     if folder not in filename:
         filename = f"{folder}{filename}"
     client.delete_object(Bucket=BUCKET_NAME, Key=filename)
@@ -352,6 +367,10 @@ def upload_to_s3_from_ram(
     if suffix not in s3_filename:
         s3_filename = f"{s3_filename}{suffix}"
     s3 = boto3.resource('s3')
+    if folder.startswith('/'):
+        folder = folder[1:]
+    if not folder.endswith('/'):
+        folder = f'{folder}/'
     body = (
         content.getvalue().encode('utf-8')
         if isinstance(content, StringIO)
